.. _installation_index:

============
Installation
============

.. warning::

    Erin is pre-alpha and highly unstable. Do not use this in production as API changes will take place rapidly without notice.

.. toctree::
   :maxdepth: 2

   Installing the bot <bot>
   Configuring a database <database>
